@@ -129,7 +129,7 @@ void ImageScaler::scaleRect(const QRect& rect)
     const qreal REAL_DELTA = 0.001;
     if (qAbs(d->mZoom - 1.0) < REAL_DELTA) {
         QImage tmp = d->mDocument->image().copy(rect);
-        tmp.convertToFormat(QImage::Format_ARGB32_Premultiplied);
+        tmp = tmp.convertToFormat(QImage::Format_ARGB32_Premultiplied);
         scaledRect(rect.left(), rect.top(), tmp);
         return;
     }
@@ -193,7 +193,7 @@ void ImageScaler::scaleRect(const QRect& rect)
 
     QImage tmp;
     tmp = image.copy(sourceRect);
-    tmp.convertToFormat(QImage::Format_ARGB32_Premultiplied);
+    tmp = tmp.convertToFormat(QImage::Format_ARGB32_Premultiplied);
     tmp = tmp.scaled(
               destRect.width(),
               destRect.height(),
